==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translation>Bemassung</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translation type="obsolete">Standard Bemassungseinstellungen</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Bemassungseinstellungen</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Standards für neue Zeichnungen</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Scientific</source>
        <translation>Wissenschaftlich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Dezimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Technisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architektur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Bruchdarstellung</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Decimal Degrees</source>
        <translation>Dezimal Grad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Grad/Min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradianten</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiant</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Vermessung</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Grössen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Proportional</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Text Höhe:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Begrenzungslinien Abstand:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Verlängerung der Begrenzungslinie:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Bemassungslinien Abstand:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Pfeil Grösse:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Skalierung für alle Grössen:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Pfeil Stil</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Architektur Tick</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Label Format</source>
        <translation>Beschriftungsformat</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Lineare Bemassungen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Format:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>&amp;Genauigkeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Nachfolgende Nullen anzeigen</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Winkel Bemassungen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormat:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>&amp;Genauigkeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../DimensionSettings.js" line="+138"/>
        <source>Unit / Format</source>
        <translation>Einheit / Format</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Die Zeichnungseinheit muss &apos;Inch&apos; sein, damit Bemassungsbeschriftungen in den Formaten &apos;Architektur&apos; oder &apos;Technisch&apos; angezeigt werden können. Format zurückgesetzt auf &apos;Dezimal&apos;.</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translation>Bemassung</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translation type="obsolete">Standard Bemassungseinstellungen</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Bemassungseinstellungen</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Standards für neue Zeichnungen</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Scientific</source>
        <translation>Wissenschaftlich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Dezimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Technisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architektur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Bruchdarstellung</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Dezimal Grad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Grad/Min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradianten</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiant</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Vermessung</translation>
    </message>
    <message>
        <location line="+194"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Die Zeichnungseinheit muss &apos;Inch&apos; oder &apos;Foot&apos; sein, damit Bemassungsbeschriftungen in den Formaten &apos;Architektur&apos; oder &apos;Technisch&apos; angezeigt werden können. Format zurückgesetzt auf &apos;Dezimal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Grössen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Proportional</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Text Höhe:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Begrenzungslinien Abstand:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Verlängerung der Begrenzungslinie:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Bemassungslinien Abstand:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Pfeil Grösse:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Skalierung für alle Grössen:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Pfeil Stil</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Architektur Tick</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Bemassungstext Schriftart:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Beschriftungsformat</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Lineare Bemassungen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Format:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>&amp;Genauigkeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Nachfolgende Nullen anzeigen</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Winkel Bemassungen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormat:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>&amp;Genauigkeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../DimensionSettings.js" line="-1"/>
        <source>Unit / Format</source>
        <translation>Einheit / Format</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">Die Zeichnungseinheit muss &apos;Inch&apos; sein, damit Bemassungsbeschriftungen in den Formaten &apos;Architektur&apos; oder &apos;Technisch&apos; angezeigt werden können. Format zurückgesetzt auf &apos;Dezimal&apos;.</translation>
    </message>
</context>
</TS>
